@@ -45,26 +45,30 @@
 
 #define SAMPLE_WATER_NUMBER     16
 
-#define RAW_MAP_MAX_NUMBER     512
-#define RAW_MAP_DAT_NUMBER      64
+#define RAW_MAP_MAX_NUMBER    1024 
+#define RAW_MAP_DAT_NUMBER     512
 
-#define RAW_TEXTURE_MAX_NUMBER  512
-#define RAW_TEXTURE_DAT_NUMBER  128
+#define RAW_TEXTURE_MAX_NUMBER 1024 
+#define RAW_TEXTURE_DAT_NUMBER  512
 
 #define LANGAGE_NUMBER      2
-#define HELP_TEXT_NUMBER    11
+#define HELP_TEXT_NUMBER    12
 
+/*
+ * these constants must be in alphabetical order
+ */
+#define HELP_TEXT_ABOUT     0
+#define HELP_TEXT_ADVANCED  1
+#define HELP_TEXT_GRAPHICS  2
 #define HELP_TEXT_MAIN      3
 #define HELP_TEXT_MAP       4
-#define HELP_TEXT_TEAMS     9
-#define HELP_TEXT_OPTIONS   5
-#define HELP_TEXT_GRAPHICS  2
-#define HELP_TEXT_WAVE      10
-#define HELP_TEXT_SOUND     8
-#define HELP_TEXT_RULES     6
-#define HELP_TEXT_ADVANCED  1
-#define HELP_TEXT_ABOUT     0
-#define HELP_TEXT_SCORE     7
+#define HELP_TEXT_NETGAME   5
+#define HELP_TEXT_OPTIONS   6
+#define HELP_TEXT_RULES     7
+#define HELP_TEXT_SCORE     8
+#define HELP_TEXT_SOUND     9
+#define HELP_TEXT_TEAMS     10
+#define HELP_TEXT_WAVE      11
 
 /*==================================================================*/
 /* variables globales                                               */
