@@ -100,5 +100,11 @@ int error_graphics_init_failed (void)
  return (standard_error("Unable to start graphic mode"));
 }
 
+/*------------------------------------------------------------------*/
+int error_no_network_support (void)
+{
+ return (standard_error("No network support"));
+}
+
 
 
