@@ -42,6 +42,7 @@
 #include "sound.h"
 #include "startup.h"
 #include "ticker.h"
+#include "sockgen.h"
 
 /*==================================================================*/
 /* types                                                            */
@@ -75,13 +76,14 @@ static void exit_all (void)
  remove_keyboard ();
  remove_timer ();
  allegro_exit ();
+ lw_sock_exit ();
 }
 
 /*------------------------------------------------------------------*/
 static void disp_base_message (void)
 {
- log_println_str("Liquid War 5.3.3 by U-Foot.");
- log_println_str("This version released on March 16th 2001.");
+ log_println_str("Liquid War " LW_VERSION " by U-Foot.");
+ log_println_str("This release compiled on " __DATE__ ".");
  log_println();
  log_println_str("E-mail    : ufoot@ufoot.org");
  log_println_str("Web       : http://www.ufoot.org/liquidwar/");
