@@ -64,6 +64,7 @@
 #include "time.h"
 #include "viewport.h"
 #include "watchdog.h"
+#include "network.h"
 
 /*==================================================================*/
 /* definitions de constantes                                        */
@@ -99,16 +100,28 @@ void calc_playing_teams(void)
   * 6 areas in the "teams" menu
   */
  for (i=0;i<NB_TEAMS;++i)
+   {
      /*
       * check if a color has been selected, a value of 0 indicates
       * that no color has been selected, therefore the team is
       * disactivated
-      */ 
+      */
+   if (LW_NETWORK_ON)
+     {
+       if (LW_NETWORK_INFO[i].active)
+	 {
+	   PLAYING_TEAMS++;
+	 }
+     }
+     else
+     { 
      if (CONFIG_TEAM_COLOR[i])
         /*
          * OK, there's a chosen color, increment the result
          */
         PLAYING_TEAMS++;
+     }
+   }
 }
 
 /*------------------------------------------------------------------*/
@@ -280,6 +293,12 @@ char  *init_game (void)
      init_disp_cursor ();
      }
 
+  /*
+   * We set the network error flag to 0, if it becomes non-zero
+   * then the game simply stops...
+   */
+  LW_NETWORK_ERROR_DETECTED=0;
+
   return message;
 }
 
@@ -598,7 +617,8 @@ int game (void)
   */
  while (  (!WATCHDOG_SCANCODE[KEY_ESC])
        && (PLAYING_TEAMS>=2)
-       && (TIME_LEFT>0))
+       && (TIME_LEFT>0)
+       && (!LW_NETWORK_ERROR_DETECTED))
      {
       /*
        * global time checking
